@@ -40,3 +40,15 @@ class Vector(NamedTuple):
 X_EPSILON = 1.0e-8
 X_OFFSET = 1.0e-8
 T_OFFSET = 1.0e-6
+
+
+class MissingOptionalModule:
+    """
+    Presents a clear error for optional modules.
+    """
+
+    def __init__(self, name):
+        self.name = name
+
+    def __getattr__(self, name):
+        raise ImportError(f"{self.name} is required for this functionality")
